Exception: Redvine::AuthenticationRequiredError

Inherits:
Error
  • Object
show all
Defined in:
lib/redvine.rb

Instance Method Summary collapse

Constructor Details

#initialize(msg = "You must authenticate as a valid Vine user (call #connect) before accessing other API methods") ⇒ AuthenticationRequiredError

Returns a new instance of AuthenticationRequiredError.



17
18
19
# File 'lib/redvine.rb', line 17

def initialize(msg="You must authenticate as a valid Vine user (call #connect) before accessing other API methods")
  super(msg)
end