Exception: Redvine::AuthenticationRequiredError
- Defined in:
- lib/redvine.rb
Instance Method Summary collapse
-
#initialize(msg = "You must authenticate as a valid Vine user (call #connect) before accessing other API methods") ⇒ AuthenticationRequiredError
constructor
A new instance of AuthenticationRequiredError.
Constructor Details
#initialize(msg = "You must authenticate as a valid Vine user (call #connect) before accessing other API methods") ⇒ AuthenticationRequiredError
Returns a new instance of AuthenticationRequiredError.
17 18 19 |
# File 'lib/redvine.rb', line 17 def initialize(msg="You must authenticate as a valid Vine user (call #connect) before accessing other API methods") super(msg) end |